/*
 * Project:		 	3-PHASE AC DRIVE
 *
 * Microcontroller: Motorola MC68HC908MR32 
 *
 * Module:			CONST.H
 * Description:		File contains global constants
 *
 * Compiler:		Hiware08 Compiler
 *
 * Author:			Radim VISINKA
 * 
 * ====================================================================
 */



/* DEFINITION_START */

										
/* Constant Definitions */

#define PWM_MODULUS		0x00fa		/* set MC PWM modulus to 16 kHz */

//#define F_TIMERA_2		0xe100		/* 1/2 of timer frequency: 1/2 * (7.3728E6 / 64) */


/* Software Timer Constants */

#define READ_CONST 		0x0073		/* read_constant timeout: 1msec=0x0073 */
									/* 5msec = 0x0240 */
#define CONTROL_CONST 		0x0480		/* PI_constant timeout: 10msec=0x0480 */
									/*     const = time*7372800/64    */


							
/* Acceleration Ramp Constants */
									
#define ACC	 			11			/* acceleration constant => 20 Hz/sec */
#define DEC	 			11			/* deceleration constant => 20 Hz/sec */

									/*  	 acceleration (Hz) * 256 * 64
									   ACC = ---------------------------- * 256 = 11
											 7.3728 * 10^6
									*/
									/* acceleration = PWM_reload / ramp_reload * accel */
									/* deceleration = PWM_reload / ramp_reload * decel */
									/* result is in 8.8 format */

/* V/Hz Ramp Constants */

#define VOLTS_BOOST		10			/* min. voltage for boost = 10% from 255 */
#define VOLTS_MIN 		9			/* min ampl. = 9% from 255 */
#define FREQ_BOOST	 	0x0f00		/* boost frequency = 15Hz*/
#define FREQ_BASE		0x3700		/* frequency base point 55Hz=0x3700, 50Hz=0x3200 25Hz=0x1900 */


/* I/O Constants and Definitions */

#define	GREEN_LED		0x10		/* Green LED on PTC4 */
#define	YELLOW_LED		0x20		/* Yellow LED on PTC5 */
#define	BRAKE_SWITCH	0x80		/* Brake switch on PTA7 */

//#define	GREEN_LED		0x38		/* Green LED on PTA 3,4,5 */
//#define	YELLOW_LED		0x07		/* Yellow LED on PTA 0,1,2 */
//#define	BRAKE_SWITCH	0x01		/* Brake switch on PTE0 */



/* Fault Routine Constants and Definitions */

#define FLT_REC_LED_FLASH 0xff 		/* flash constant of fault LED */
#define REC_TIME	0x1388		/* 5000 * speed routine enter */
#define DCB_VOLT_LIMIT	227		/* overvoltage limit */
									/* 390V = 4.43Vsensed = 227 */
#define DEC_LOW_DCB_V	198		/* low limit of DCB during deceleration */
									/* 340V=3.86Vsensed=198 */

#define	DEC_HIGH_DCB_V	215		/* high limit of DCB during deceleration */
									/* 370V=4.2Vsensed=215 */
									/* Vsensed = 0.0113636 * Vdcb */



/* Fault Register Definition  >>Fault_flags<< */

#define	OVER_VOLTAGE	0x01
#define	OVER_CURRENT	0x02
#define	SAFETY_STOP		0x04
#define 	OV_DEC_FLAG		0x80


/* MCS Status Register Definition >>Mcs_status<< */

#define	GF_FLAG			0x01
#define	GFR_FLAG		0x02
#define	MCS_STAND_BY	0x04
#define	MCS_STOP		0x08
#define	MCS_RUN			0x10
#define START_STOP_FLG	0x20
#define MCS_ACCEL		0x40	


/*	authorize interrupts*/

#define cli()	asm cli
#define sei()   asm sei 
				

/* DEFINITION_END */
