/*
 * Project:		    3-PHASE AC DRIVE
 *
 * Microcontroller: Motorola MC68HC908MR32 
 *
 * Module:			FAULT.C
 * Description:		This interrupt routine is responsible for
 *                	 - handling an overcurrent fault sensed on 
 *					pin PTD1 - FAULT2	
 *                	 - handling an safety stop fault sensed on 
 *					pin PTD3 - FAULT4	
 *
 * Compiler:		Hiware08 Compiler
 *
 * Author:			Radim VISINKA
 *
 * ====================================================================
 */


/* DEFINITION_START */


/* Include Header Files */
#include "MR32IO.H"
#include "CONST.H"			/* file contains global constants and
							   definitions */

/* Assembler Subroutine Definitions */

/* Constant Definitions */

/* Global Variables (External) - 8 bit */
extern unsigned char Fault_flags;		/* 8 bit fault flag register */

/* Global Variables (External) - 16 bit */

/* Local Variables - 8 bit */

/* Local Variables - 16 bit */
			  

/* DEFINITION_END */


void fault (void)
	{
	PCTL1 |= 0xc0;				   /* disable MCPWM */
	Fault_flags |= OVER_CURRENT;  	   /* set overcurrent flag */
	FTAC |= 0x04;					/* clears FFLAG2 - fault2 flag bit */
	}



void safety_stop(void)
	{
	PCTL1 |= 0xc0;				   /* disable MCPWM */
	Fault_flags |= SAFETY_STOP;  	   /* set overcurrent flag */
	FTAC |= 0x40;					/* clears FFLAG4 - fault4 flag bit */
	}
